<?php
// Start session and include database connection
session_start();
require 'db.php'; // Ensure this file is correct and properly configured

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    // Redirect to login page if user is not logged in
    header('Location: login.php');
    exit();
}

// Get user data from session
$user_id = $_SESSION['user_id'];

// Fetch user information from the database
$stmt = $conn->prepare("SELECT first_name, last_name, phone_number FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
} else {
    die("User not found."); // Handle the case if the user ID is invalid
}
$stmt->close();

// Initialize error variables
$error = '';
$success = false;

// Check if the form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get submitted form data
    $first_name = $_POST['first_name'];
    $last_name = $_POST['last_name'];
    $phone_number = $_POST['phone_number'];
    
    $current_password = $_POST['current_password'] ?? '';
    $new_password = $_POST['new_password'] ?? '';
    $confirm_password = $_POST['confirm_password'] ?? '';

    // Validate the password fields if the new password is set
    if (!empty($new_password) || !empty($confirm_password)) {
        // Check if the passwords match
        if ($new_password !== $confirm_password) {
            $error = 'New passwords do not match.';
        } else {
            // Check if the current password is correct
            $stmt = $conn->prepare("SELECT password FROM users WHERE id = ?");
            $stmt->bind_param("i", $user_id);
            $stmt->execute();
            $stmt->bind_result($stored_password);
            $stmt->fetch();
            $stmt->close();

            if (password_verify($current_password, $stored_password)) {
                // Update password
                $new_password_hash = password_hash($new_password, PASSWORD_DEFAULT);
                $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
                $stmt->bind_param("si", $new_password_hash, $user_id);
                $stmt->execute();
                $stmt->close();

                $success = true;
            } else {
                $error = 'Current password is incorrect.';
            }
        }
    }

    // If no password is being changed, update other info
    if (empty($error)) {
        $stmt = $conn->prepare("UPDATE users SET first_name = ?, last_name = ?, phone_number = ? WHERE id = ?");
        $stmt->bind_param("sssi", $first_name, $last_name, $phone_number, $user_id);
        if ($stmt->execute()) {
            $success = true;
        } else {
            $error = 'Failed to update profile information.';
        }
        $stmt->close();
    }
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Update Profile</title>
    <style>
        /* Add your styling here */
        body {
            font-family: Arial, sans-serif;
            background-color: #141414;
            color: #fff;
            margin: 0;
            padding: 0;
        }
        .container {
            width: 80%;
            max-width: 800px;
            margin: 50px auto;
            padding: 20px;
            background-color: #1a1a1a;
            border-radius: 10px;
            border-radius: 15px;
            box-shadow: 0 0 15px rgba(0, 0, 0, 0.2);
            border: 3px solid #ffcc00; 
        }
        .container h1 {
            text-align: center;
        }
        .form-group {
            margin-bottom: 20px;
        }
        .form-group label {
            display: block;
            margin-bottom: 8px;
        }
        .form-group input {
            width: 100%;
            padding: 10px;
            margin-bottom: 10px;
            border-radius: 5px;
            border: 1px solid #333;
            background-color: #222;
            color: #fff;
        }
        .form-group input[type="submit"] {
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            color: white;
            border: none;
        }
        .form-group input[type="submit"]:hover {
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            transform: scale(1.05);
        }
        .error {
            color: red;
            text-align: center;
        }
        .success {
            color: green;
            text-align: center;
        }
        

    </style>
</head>
<body>

<div class="container">
    <h1>Update Profile</h1>

    <?php if ($error): ?>
        <div class="error"><?php echo htmlspecialchars($error); ?></div>
    <?php elseif ($success): ?>
        <div class="success">Profile updated successfully!</div>
    <?php endif; ?>

    <form action="update_profile.php" method="POST">
        <!-- Hidden field for user ID (not editable) -->
        <input type="hidden" name="user_id" value="<?php echo $user_id; ?>">

        <div class="form-group">
            <label for="first_name">First Name</label>
            <input type="text" name="first_name" id="first_name" value="<?php echo htmlspecialchars($user['first_name']); ?>" required>
        </div>

        <div class="form-group">
            <label for="last_name">Last Name</label>
            <input type="text" name="last_name" id="last_name" value="<?php echo htmlspecialchars($user['last_name']); ?>" required>
        </div>

        <div class="form-group">
            <label for="phone_number">Phone Number</label>
            <input type="text" name="phone_number" id="phone_number" value="<?php echo htmlspecialchars($user['phone_number']); ?>" required>
        </div>

        <div class="form-group">
            <label for="current_password">Current Password</label>
            <input type="password" name="current_password" id="current_password" placeholder="Enter your current password">
        </div>

        <div class="form-group">
            <label for="new_password">New Password</label>
            <input type="password" name="new_password" id="new_password" placeholder="Enter a new password">
        </div>

        <div class="form-group">
            <label for="confirm_password">Confirm New Password</label>
            <input type="password" name="confirm_password" id="confirm_password" placeholder="Confirm the new password">
        </div>

        <div class="form-group">
            <input type="submit" value="Update Profile">
        </div>
    </form>
</div>

</body>
</html>
